==> gcontactsync_0.2.8.orig.tar.gz: gcontactsync-0.2.8/content/ConverterElement.js <==
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is gContactSync.
 *
 * The Initial Developer of the Original Code is
 * Josh Geenen <gcontactsync@pirules.net>.
 * Portions created by the Initial Developer are Copyright (C) 2008
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
/**
 * ConverterElement
 * Creates a new object used to convert data between a contact's XML
 * representation and an address book card.
 * @param aElementName The name of the GElement, in gdata.contacts to use.
 * @param aTbName      The name of the attribute in Thunderbird.
 * @param aIndex       The index of the element to retrieve, if non-zero.
 * @param aType        The "type" of data as shown in the 'rel' attribute in the
 *                     XML feed after the pound sign (#).
 *                     Examples include 'home', 'work', and 'other'
 * @constructor
 * @class
 */
function ConverterElement(aElementName, aTbName, aIndex, aType) {
  this.elementName = aElementName;
  this.tbName = aTbName;
  this.index = aIndex;
  this.type = aType;
}

==> gcontactsync_0.3.4.orig.tar.gz: gcontactsync-0.3.4/content/ConverterElement.js <==
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is gContactSync.
 *
 * The Initial Developer of the Original Code is
 * Josh Geenen <gcontactsync@pirules.org>.
 * Portions created by the Initial Developer are Copyright (C) 2008
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

if (!com) var com = {}; // A generic wrapper variable
// A wrapper for all GCS functions and variables
if (!com.gContactSync) com.gContactSync = {};

/**
 * Creates a new object used to convert data between a contact's XML
 * representation and an address book card.
 * @param aElementName {string} The name of the GElement, in gdata.contacts, to
 *                              use.
 * @param aTbName      {string} The name of the attribute in Thunderbird.
 * @param aIndex       {integer} The index of the element to retrieve, if
 *                               non-zero.
 * @param aType        {string} The "type" of data as shown in the 'rel'
 *                              attribute in the XML feed after the pound sign.
 *                              Examples include 'home', 'work', and 'other'
 * @constructor
 * @class
 */
com.gContactSync.ConverterElement = function gCS_ConverterElement(aElementName, aTbName, aIndex, aType) {
  this.elementName = aElementName;
  this.tbName      = aTbName;
  this.index       = aIndex;
  this.type        = aType;
}
